@@ -1,4 +1,4 @@
-# Copyright (c) 2018-2020 Micro Focus or one of its affiliates.
+# Copyright (c) 2018-2021 Micro Focus or one of its affiliates.
 # Copyright (c) 2018 Uber Technologies, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -40,6 +40,7 @@ import re
 from collections import namedtuple
 from datetime import date, datetime
 from decimal import Decimal
+from six import PY2
 from uuid import UUID
 
 # noinspection PyCompatibility,PyUnresolvedReferences
@@ -133,11 +134,35 @@ def time_parse(s):
         return datetime.strptime(s, '%H:%M:%S').time()
     return datetime.strptime(s, '%H:%M:%S.%f').time()
 
+def binary_data_parse(s):
+    """
+    Parses text value of a BINARY/VARBINARY/LONG VARBINARY type.
+    :param s: bytearray
+    :return: bytes
+    """
+    buf = []
+    i = 0
+    while i < len(s):
+        c = s[i: i+1]
+        if c == b'\\':
+            c2 = s[i+1: i+2]
+            if c2 == b'\\':  # escaped \
+                if PY2: c = str(c)
+                i += 2
+            else:   # A \xxx octal string
+                c = chr(int(str(s[i+1: i+4]), 8)) if PY2 else bytes([int(s[i+1: i+4], 8)])
+                i += 4
+        else:
+            if PY2: c = str(c)
+            i += 1
+        buf.append(c)
+    return b''.join(buf)
+
 
 # Type casting of SQL types bytes representation into Python objects
 def vertica_type_cast(type_code, unicode_error):
     typecaster = {
-        VerticaType.UNKNOWN: None,
+        VerticaType.UNKNOWN: bytes,
         VerticaType.BOOL: lambda s: s == b't',
         VerticaType.INT8: lambda s: int(s),
         VerticaType.FLOAT8: lambda s: float(s),
@@ -147,17 +172,17 @@ def vertica_type_cast(type_code, unicode_error):
         VerticaType.TIME: time_parse,
         VerticaType.TIMESTAMP: timestamp_parse,
         VerticaType.TIMESTAMPTZ: timestamp_tz_parse,
-        VerticaType.INTERVAL: None,
-        VerticaType.TIMETZ: None,
+        VerticaType.INTERVAL: bytes,
+        VerticaType.TIMETZ: bytes,
         VerticaType.NUMERIC: lambda s: Decimal(s.decode('utf-8', unicode_error)),
-        VerticaType.VARBINARY: None,
+        VerticaType.VARBINARY: binary_data_parse,
         VerticaType.UUID: lambda s: UUID(s.decode('utf-8', unicode_error)),
-        VerticaType.INTERVALYM: None,
+        VerticaType.INTERVALYM: bytes,
         VerticaType.LONGVARCHAR: lambda s: s.decode('utf-8', unicode_error),
-        VerticaType.LONGVARBINARY: None,
-        VerticaType.BINARY: None
+        VerticaType.LONGVARBINARY: binary_data_parse,
+        VerticaType.BINARY: binary_data_parse
     }
-    return typecaster.get(type_code, None)
+    return typecaster.get(type_code, bytes)
 
 
 ColumnTuple = namedtuple('Column', ['name', 'type_code', 'display_size', 'internal_size',
@@ -183,7 +208,7 @@ class Column(object):
     def convert(self, s):
         if s is None:
             return
-        return self.converter(s) if self.converter is not None else s
+        return self.converter(s)
 
     def __str__(self):
         return as_str(str(self.props))
